@@ -172,6 +172,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub use checkout_core::error::Error;
             pub use checkout_core::error::new_server_error;
             pub use checkout_core::server::Server;
+            pub use checkout_core::server::spawn_token_renew;
             pub use checkout_core::internal_context::InternalContext;
             pub use checkout_core::db::DBClient;
 
@@ -198,7 +199,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             use checkout_core::customer::Contact;
             use checkout_core::customer::Address;
             use checkout_core::money::Currency;
-            use checkout_core::shipping::FulfillmentTypeSelection;
+            use checkout_core::shipping::FulfillmentSelection;
             use checkout_core::transaction::TransactionController;
             use checkout_core::context::{Context, ClientContext};
             use checkout_core::context::ClientContextProvider;
@@ -212,7 +213,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 confirm_items_handler,
                 update_contact_handler,
                 update_shipping_address_handler,
-                update_fulfillment_type_handler,
+                update_fulfillment_handler,
                 initiate_payment_handler,
                 step_payment_handler as step_checkout_payment_handler,
                 initiate_order_handler,
@@ -651,17 +652,17 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             #[endpoint {
                 method = PATCH,
-                path = "/checkout/{id}/update_fulfillment_type",
+                path = "/checkout/{id}/update_fulfillment",
             }]
-            pub async fn update_checkout_fulfillment_type(
+            pub async fn update_checkout_fulfillment(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<FulfillmentTypeSelection>,
+                body: TypedBody<FulfillmentSelection>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data
             >>>, HttpError> {
                 let path_params = path.into_inner();
-                let fulfillment_type = body.into_inner();
+                let fulfillment_selection = body.into_inner();
                 let mut ctx = req_ctx
                     .context()
                     .context_provider
@@ -670,7 +671,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                     .unwrap();
 
                 ctx.start_transaction().await.unwrap();
-                match update_fulfillment_type_handler(&mut ctx, &path_params.id, fulfillment_type).await {
+                match update_fulfillment_handler(&mut ctx, &path_params.id, fulfillment_selection).await {
                     Ok(co) => {
                         ctx.commit_transaction().await.unwrap();
                         Ok(HttpResponseOk(co))
@@ -689,7 +690,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_checkout_payment(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
+                body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::InitArgs>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data
             >>>, HttpError> {
@@ -760,7 +761,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn initiate_checkout_order(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-                body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
+                body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::InitArgs>,
             ) -> Result<HttpResponseOk<Checkout<Payment<
                 <super::#context_type_name #ty_static_generics as PaymentProcessor>::Data
             >>>, HttpError> {
@@ -947,7 +948,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 api.register(checkout_server::confirm_checkout_items).unwrap();
                 api.register(checkout_server::update_checkout_contact).unwrap();
                 api.register(checkout_server::update_checkout_shipping_address).unwrap();
-                api.register(checkout_server::update_checkout_fulfillment_type).unwrap();
+                api.register(checkout_server::update_checkout_fulfillment).unwrap();
                 api.register(checkout_server::initiate_checkout_payment).unwrap();
                 api.register(checkout_server::step_checkout_payment).unwrap();
                 api.register(checkout_server::initiate_checkout_order).unwrap();
@@ -981,7 +982,7 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 ));
 
                 let pubsub_client = internal_context.pubsub_client.clone();
-                pubsub_client.spawn_token_renew(checkout_server::Duration::from_secs(15 * 60));
+                checkout_server::spawn_token_renew(&pubsub_client, checkout_server::Duration::from_secs(15 * 60));
 
                 checkout_server::process_payment_callbacks(internal_context.clone(), context_provider.clone());
                 checkout_server::process_order_events(internal_context.clone(), context_provider.clone());
